==> haskell-hxt-regex-xmlschema-9.2.0.3-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-regex-xmlschema.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-regex-xmlschema
version: 9.2.0.3
id: hxt-regex-xmlschema-9.2.0.3-IFZJv7dtYpI7USZZhsGoJV
key: hxt-regex-xmlschema-9.2.0.3-IFZJv7dtYpI7USZZhsGoJV
license: MIT
copyright: Copyright (c) 2010- Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
author: Uwe Schmidt
stability: stable
homepage: http://www.haskell.org/haskellwiki/Regular_expressions_for_XML_Schema
synopsis: A regular expression library for W3C XML Schema regular expressions
description:
    This library supports full W3C XML Schema regular expressions
    inclusive all Unicode character sets and blocks.
    The complete grammar can be found under <http://www.w3.org/TR/xmlschema11-2/#regexs>.
    It is implemented by the technique of derivations of regular expressions.
    .
    The W3C syntax is extended to support not only union of regular sets,
    but also intersection, set difference, exor.
    Matching of subexpressions is also supported.
    .
    The library can be used for constricting lightweight scanners and tokenizers.
    It is a standalone library, no external regex libraries are used.
    .
    Extensions in 9.2: The library does nor only support String'\''s, but also
    ByteString'\''s and Text in strict and lazy variants
category: Text
abi: c2665aec1c67db9521ceb85d3f3ad156
exposed: True
exposed-modules:
    Text.Regex.Glob.Generic Text.Regex.Glob.Generic.RegexParser
    Text.Regex.Glob.String Text.Regex.XMLSchema.Generic
    Text.Regex.XMLSchema.Generic.Matching
    Text.Regex.XMLSchema.Generic.Regex
    Text.Regex.XMLSchema.Generic.RegexParser
    Text.Regex.XMLSchema.Generic.StringLike Text.Regex.XMLSchema.String
import-dirs: /usr/lib/ghc-8.4.3/site-local/hxt-regex-xmlschema-9.2.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/hxt-regex-xmlschema-9.2.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hxt-regex-xmlschema-9.2.0.3
hs-libraries: HShxt-regex-xmlschema-9.2.0.3-IFZJv7dtYpI7USZZhsGoJV
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    hxt-charproperties-9.2.0.1-DFKuHAMsc8NJwk1yc4YSyO parsec-3.1.13.0
    text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             hxt-charproperties-9.2.0.1-DFKuHAMsc8NJwk1yc4YSyO=44ab63d147932ce734e2efa3c8ca00f5
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-hxt-regex-xmlschema/html/hxt-regex-xmlschema.haddock
haddock-html: /usr/share/doc/haskell-hxt-regex-xmlschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-regex-xmlschema-9.2.0.3-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-regex-xmlschema.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-regex-xmlschema
version: 9.2.0.3
id: hxt-regex-xmlschema-9.2.0.3-4yBnSFZIMvYEjojwDBjhTl
key: hxt-regex-xmlschema-9.2.0.3-4yBnSFZIMvYEjojwDBjhTl
license: MIT
copyright: Copyright (c) 2010- Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
author: Uwe Schmidt
stability: stable
homepage: http://www.haskell.org/haskellwiki/Regular_expressions_for_XML_Schema
synopsis: A regular expression library for W3C XML Schema regular expressions
description:
    This library supports full W3C XML Schema regular expressions
    inclusive all Unicode character sets and blocks.
    The complete grammar can be found under <http://www.w3.org/TR/xmlschema11-2/#regexs>.
    It is implemented by the technique of derivations of regular expressions.
    .
    The W3C syntax is extended to support not only union of regular sets,
    but also intersection, set difference, exor.
    Matching of subexpressions is also supported.
    .
    The library can be used for constricting lightweight scanners and tokenizers.
    It is a standalone library, no external regex libraries are used.
    .
    Extensions in 9.2: The library does nor only support String'\''s, but also
    ByteString'\''s and Text in strict and lazy variants
category: Text
abi: 3f8879a71f708268dabb523f3e131b5e
exposed: True
exposed-modules:
    Text.Regex.Glob.Generic Text.Regex.Glob.Generic.RegexParser
    Text.Regex.Glob.String Text.Regex.XMLSchema.Generic
    Text.Regex.XMLSchema.Generic.Matching
    Text.Regex.XMLSchema.Generic.Regex
    Text.Regex.XMLSchema.Generic.RegexParser
    Text.Regex.XMLSchema.Generic.StringLike Text.Regex.XMLSchema.String
import-dirs: /usr/lib/ghc-8.6.1/site-local/hxt-regex-xmlschema-9.2.0.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/hxt-regex-xmlschema-9.2.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/hxt-regex-xmlschema-9.2.0.3
hs-libraries: HShxt-regex-xmlschema-9.2.0.3-4yBnSFZIMvYEjojwDBjhTl
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    hxt-charproperties-9.2.0.1-FrM4lHkFZYa1rulBEgP7qk parsec-3.1.13.0
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-hxt-regex-xmlschema/html/hxt-regex-xmlschema.haddock
haddock-html: /usr/share/doc/haskell-hxt-regex-xmlschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
